#########
DATMapper
#########

The DATMapper will compare checksums between ROMs in two DAT files, and provide mappings between ROMs that may have
changed name.

DATMapper has no specific arguments.

API
===

.. autoclass:: romsearch.DATMapper
    :no-index:
    :members:
    :undoc-members: